@@ -32,7 +32,6 @@
 
 #ifdef HAVE_POLKIT
 #include <polkit/polkit.h>
-#include <polkit-dbus/polkit-dbus.h>
 #endif
 
 #ifdef HAVE_GIO
@@ -67,7 +66,7 @@ struct StbDispatcherPrivate
   gchar *platform;
 
 #ifdef HAVE_POLKIT
-  PolKitContext *polkit_context;
+  PolkitAuthority *polkit_authority;
 #endif
 
 #ifdef HAVE_GIO
@@ -167,7 +166,7 @@ dispatch_file_list (DBusPendingCall *pending_call,
 
   if (dbus_set_error_from_message (&error, reply))
     {
-      g_critical (error.message);
+      g_critical ("%s", error.message);
       dbus_error_free (&error);
       dbus_message_unref (reply);
       return;
@@ -184,7 +183,7 @@ dispatch_file_list (DBusPendingCall *pending_call,
     }
   else
     {
-      g_critical (error.message);
+      g_critical ("%s", error.message);
     }
 
   dbus_message_unref (reply);
@@ -264,7 +263,7 @@ dispatch_reply (DBusPendingCall *pending_call,
 
   if (dbus_set_error_from_message (&error, reply))
     {
-      g_warning (error.message);
+      g_warning ("%s", error.message);
       dbus_error_free (&error);
     }
 
@@ -319,12 +318,16 @@ can_caller_do_action (StbDispatcher *dispatcher,
 {
 #ifdef HAVE_POLKIT
   StbDispatcherPrivate *priv;
-  PolKitAction *action;
-  PolKitCaller *caller;
-  DBusError error;
-  PolKitResult result;
+  PolkitSubject *subject;
+  PolkitAuthorizationResult *result;
   const gchar *member;
   gchar *action_id;
+  gulong caller_pid;
+  gboolean retval;
+  GError *gerror = NULL;
+  DBusError dbus_error;
+  DBusMessage *call, *reply;
+  const gchar *connection_name;
 
   /* Allow getting information */
   if (dbus_message_has_member (message, "get"))
@@ -339,33 +342,66 @@ can_caller_do_action (StbDispatcher *dispatcher,
 
   g_return_val_if_fail (member != NULL, FALSE);
 
-  action = polkit_action_new ();
-
   if (name)
     action_id = g_strdup_printf ("org.freedesktop.systemtoolsbackends.%s.%s", name, member);
   else
     action_id = g_strdup_printf ("org.freedesktop.systemtoolsbackends.%s", member);
 
-  polkit_action_set_action_id (action, action_id);
-  g_free (action_id);
+  /* Get the caller's PID using the connection name */
+  call = dbus_message_new_method_call ("org.freedesktop.DBus",
+				       "/org/freedesktop/DBus",
+				       "org.freedesktop.DBus",
+				       "GetConnectionUnixProcessID");
+  connection_name = dbus_message_get_sender (message);
+  dbus_message_append_args (call, DBUS_TYPE_STRING, &connection_name, DBUS_TYPE_INVALID);
 
-  dbus_error_init (&error);
-  caller = polkit_caller_new_from_dbus_name (priv->connection, dbus_message_get_sender (message), &error);
+  dbus_error_init (&dbus_error);
 
-  if (dbus_error_is_set (&error))
+  reply = dbus_connection_send_with_reply_and_block (priv->connection, call, -1, &dbus_error);
+  if (dbus_error_is_set (&dbus_error))
+    goto dbus_error;
+
+  dbus_message_get_args (reply, &dbus_error, DBUS_TYPE_UINT32, &caller_pid, DBUS_TYPE_INVALID);
+  if (dbus_error_is_set (&dbus_error))
+    goto dbus_error;
+
+  dbus_message_unref (call);
+  dbus_message_unref (reply);
+
+  /* We need to identify the subject using its PID
+   * because it's how PolkitLockButton works on the client side */
+  subject = polkit_unix_process_new (caller_pid);
+  result = polkit_authority_check_authorization_sync (priv->polkit_authority, subject, action_id, NULL,
+                                                      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
+                                                      NULL, &gerror);
+
+  g_object_unref (subject);
+
+  if (gerror)
     {
-      g_critical (error.message);
-      dbus_error_free (&error);
+      g_critical ("%s", gerror->message);
+      g_error_free (gerror);
+      g_free (action_id);
 
       return FALSE;
     }
 
-  result = polkit_context_can_caller_do_action (priv->polkit_context, action, caller);
+  retval = polkit_authorization_result_get_is_authorized (result);
 
-  polkit_caller_unref (caller);
-  polkit_action_unref (action);
+  DEBUG (dispatcher,
+	 (retval) ? "subject is allowed to do action '%s'" : "subject can't do action '%s'",
+	 action_id);
 
-  return (result == POLKIT_RESULT_YES);
+  g_free (action_id);
+
+  return retval;
+
+  dbus_error:
+    g_critical ("Could not get PID of the caller: %s", dbus_error.message);
+    dbus_error_free (&dbus_error);
+    g_free (action_id);
+
+    return FALSE;
 #else
   return TRUE;
 #endif /* HAVE_POLKIT */
@@ -590,7 +626,7 @@ setup_connection (StbDispatcher *dispatcher)
 
   if (dbus_error_is_set (&error))
     {
-      g_critical (error.message);
+      g_critical ("%s", error.message);
       dbus_error_free (&error);
     }
 
@@ -600,7 +636,7 @@ setup_connection (StbDispatcher *dispatcher)
 
   if (dbus_error_is_set (&error))
     {
-      g_critical (error.message);
+      g_critical ("%s", error.message);
       dbus_error_free (&error);
     }
 
@@ -621,8 +657,7 @@ stb_dispatcher_init (StbDispatcher *dispatcher)
   g_assert (priv->connection != NULL);
 
 #ifdef HAVE_POLKIT
-  priv->polkit_context = polkit_context_new ();
-  polkit_context_init (priv->polkit_context, NULL);
+  priv->polkit_authority = polkit_authority_get ();
 #endif
 
 #ifdef HAVE_GIO
@@ -677,7 +712,7 @@ stb_dispatcher_finalize (GObject *object)
   dbus_connection_unref (priv->connection);
 
 #ifdef HAVE_POLKIT
-  polkit_context_unref  (priv->polkit_context);
+  g_object_unref (priv->polkit_authority);
 #endif
 
 #ifdef HAVE_GIO
